==> ocaml-examples-3.11.tbz: share/examples/ocaml/camltk/bonjour.ml <==
(***********************************************************************)
(*                                                                     *)
(*                           Objective Caml                            *)
(*                                                                     *)
(*               Pierre Weis, projet Cristal, INRIA Rocquencourt       *)
(*                                                                     *)
(*  Copyright 2001 Institut National de Recherche en Informatique et   *)
(*  en Automatique.  All rights reserved.  This file is distributed    *)
(*  only by permission.                                                *)
(*                                                                     *)
(***********************************************************************)

(* $Id: bonjour.ml,v 1.3 2009/11/13 20:16:33 weis Exp $ *)

(* Le programme interactif [bonjour]: on cre un bouton qui, lorsqu'il
   est press, appelle une fonction qui crit "Bonjour!" au terminal.

Compilation:
 ocamlc -I +labltk -c bonjour.ml
dition des liens
 ocamlc -I +labltk -custom labltk.cma  bonjour.cmo -o bonjour

Essayez en lanant ./bonjour

*)

open Camltk;;

let action () = print_string "Bonjour!"; print_newline ();;

let bonjour () =
  let fentre_principale = openTk () in
  let bouton_press =
    Button.create fentre_principale
      [Text "Pressez-moi"; Command action] in
  pack [bouton_press] [];
  mainLoop ()
;;

if !Sys.interactive then () else begin bonjour (); closeTk () end;;

==> ocaml-examples-3.12.tbz: share/examples/ocaml/camltk/bonjour.ml <==
(***********************************************************************)
(*                                                                     *)
(*                        Caml examples                                *)
(*                                                                     *)
(*            Pierre Weis                                              *)
(*                                                                     *)
(*                        INRIA Rocquencourt                           *)
(*                                                                     *)
(*  Copyright (c) 1994-2011, INRIA                                     *)
(*  All rights reserved.                                               *)
(*                                                                     *)
(*  Distributed under the BSD license.                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: bonjour.ml,v 1.4 2011-08-08 19:31:17 weis Exp $ *)

(* Le programme interactif [bonjour]: on cre un bouton qui, lorsqu'il
   est press, appelle une fonction qui crit "Bonjour!" au terminal.

Compilation:
 ocamlc -I +labltk -c bonjour.ml
dition des liens
 ocamlc -I +labltk -custom labltk.cma  bonjour.cmo -o bonjour

Essayez en lanant ./bonjour

*)

open Camltk;;

let action () = print_string "Bonjour!"; print_newline ();;

let bonjour () =
  let fentre_principale = openTk () in
  let bouton_press =
    Button.create fentre_principale
      [Text "Pressez-moi"; Command action] in
  pack [bouton_press] [];
  mainLoop ()
;;

if !Sys.interactive then () else begin bonjour (); closeTk () end;;
